==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ToolActionLabelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionLabelDescription } from "./ToolActionLabelDescription";
/**
 * @hidden
 */
export let ToolActionLabelDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionLabelDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionLabelDescriptionMetadata.a == null) {
                ToolActionLabelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionLabelDescriptionMetadata.c(ToolActionLabelDescriptionMetadata.a);
            }
            if (a.j(ToolActionLabelDescriptionMetadata.a)) {
                return;
            }
            a.y(ToolActionLabelDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionLabelDescriptionMetadata.b(a);
            a.aa("ToolActionLabel", () => new ToolActionLabelDescription());
            a.z("ToolActionLabel", ToolActionLabelDescriptionMetadata.a);
        }
    }
    ToolActionLabelDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionLabelDescriptionMetadata, 'ToolActionLabelDescriptionMetadata');
    ToolActionLabelDescriptionMetadata.a = null;
    return ToolActionLabelDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ToolActionLabelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionLabelDescription } from "./ToolActionLabelDescription";
/**
 * @hidden
 */
export let ToolActionLabelDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionLabelDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionLabelDescriptionMetadata.a == null) {
                ToolActionLabelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionLabelDescriptionMetadata.c(ToolActionLabelDescriptionMetadata.a);
            }
            if (a.k(ToolActionLabelDescriptionMetadata.a)) {
                return;
            }
            a.aa(ToolActionLabelDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionLabelDescriptionMetadata.b(a);
            a.ac("ToolActionLabel", () => new ToolActionLabelDescription());
            a.ab("ToolActionLabel", ToolActionLabelDescriptionMetadata.a);
        }
    }
    ToolActionLabelDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionLabelDescriptionMetadata, 'ToolActionLabelDescriptionMetadata');
    ToolActionLabelDescriptionMetadata.a = null;
    return ToolActionLabelDescriptionMetadata;
})();
